@@ -14,7 +14,14 @@ from contextlib import contextmanager
 import warnings
 
 from selenium.webdriver.common.alert import Alert
-from selenium.common.exceptions import ElementClickInterceptedException, NoSuchElementException, WebDriverException, StaleElementReferenceException, TimeoutException
+from selenium.common.exceptions import (
+    ElementClickInterceptedException,
+    NoSuchElementException,
+    WebDriverException,
+    StaleElementReferenceException,
+    TimeoutException,
+    MoveTargetOutOfBoundsException,
+)
 from selenium.webdriver.common.action_chains import ActionChains
 from selenium.webdriver.support import expected_conditions as EC
 from selenium.webdriver.support.ui import WebDriverWait
@@ -22,6 +29,7 @@ from selenium.webdriver.support.ui import WebDriverWait
 from six import BytesIO
 
 from splinter.driver import DriverAPI, ElementAPI
+from splinter.driver.find_links import FindLinks
 from splinter.driver.xpath_utils import _concat_xpath_from_str
 from splinter.element_list import ElementList
 
@@ -181,48 +189,6 @@ class Windows(object):
         )
 
 
-class FindLinks(object):
-    """Contains methods for finding links in a parent.
-
-    Accessed through the browser object or an element via the links attribute.
-
-    Example:
-
-        browser.links.find_by_href('foobar')
-
-    """
-    def __init__(self, parent):
-        self.parent = parent
-
-    def find_by_href(self, href):
-        return self.parent.find_by_xpath(
-            '//a[@href="{}"]'.format(href),
-            original_find="link by href",
-            original_query=href,
-        )
-
-    def find_by_partial_href(self, partial_href):
-        return self.parent.find_by_xpath(
-            '//a[contains(@href, "{}")]'.format(partial_href),
-            original_find="link by partial href",
-            original_query=partial_href,
-        )
-
-    def find_by_partial_text(self, partial_text):
-        return self.parent.find_by_xpath(
-            '//a[contains(normalize-space(.), "{}")]'.format(partial_text),
-            original_find="link by partial text",
-            original_query=partial_text,
-        )
-
-    def find_by_text(self, text):
-        return self.parent.find_by_xpath(
-            '//a[text()="{}"]'.format(text),
-            original_find="link by text",
-            original_query=text,
-        )
-
-
 def _find(self, finder, selector):
     """Search for elements. Returns a list of results.
 
@@ -292,7 +258,6 @@ class BaseWebDriver(DriverAPI):
 
     def __init__(self, wait_time=2):
         self.wait_time = wait_time
-        self.ori_window_size = None
 
         self.links = FindLinks(self)
 
@@ -572,12 +537,15 @@ class BaseWebDriver(DriverAPI):
     )
 
     def find_by_value(self, value, wait_time=None):
-        return self.find_by_xpath(
+        elem = self.find_by_xpath(
             '//*[@value="{}"]'.format(value),
             original_find="value",
             original_query=value,
             wait_time=wait_time,
         )
+        if elem:
+            return elem
+        return self.find_by_xpath('//*[.="%s"]' % value)
 
     def find_by_text(self, text=None, wait_time=None):
         xpath_str = _concat_xpath_from_str(text)
@@ -662,10 +630,14 @@ class BaseWebDriver(DriverAPI):
         os.close(fd)
 
         if full:
+            ori_window_size = self.driver.get_window_size()
             self.full_screen()
 
         self.driver.get_screenshot_as_file(filename)
-        self.recover_screen()
+
+        if full:
+            self.recover_screen(ori_window_size)
+
         return filename
 
     def select(self, name, value):
@@ -685,17 +657,14 @@ class BaseWebDriver(DriverAPI):
             pass
 
     def full_screen(self):
-        self.ori_window_size = self.driver.get_window_size()
         width = self.driver.execute_script("return Math.max(document.body.scrollWidth, document.body.offsetWidth);")
         height = self.driver.execute_script("return Math.max(document.body.scrollHeight, document.body.offsetHeight);")
         self.driver.set_window_size(width, height)
 
-    def recover_screen(self):
-        if self.ori_window_size:
-            width = self.ori_window_size.get('width')
-            height = self.ori_window_size.get('height')
-            self.driver.set_window_size(width, height)
-            self.ori_window_size = None
+    def recover_screen(self, size):
+        width = size.get('width')
+        height = size.get('height')
+        self.driver.set_window_size(width, height)
 
     def html_snapshot(self, name="", suffix=".html", encoding='utf-8'):
         """Write the current html to a file."""
@@ -852,11 +821,12 @@ class WebDriverElement(ElementAPI):
             wait_time=wait_time,
         )
 
-    def find_by_xpath(self, selector, wait_time=None):
+    def find_by_xpath(self, selector, wait_time=None, original_find="xpath", original_query=None):
         return self.find_by(
             self._element.find_elements_by_xpath,
             selector,
-            original_find="xpath",
+            original_find=original_find,
+            original_query=original_query,
             wait_time=wait_time,
         )
 
@@ -930,8 +900,15 @@ class WebDriverElement(ElementAPI):
 
         """
         self.scroll_to()
-        ActionChains(self.driver).move_to_element_with_offset(
-            self._element, -10, -10).click().perform()
+        size = self._element.size
+
+        try:
+            # Fails on left edge of viewport
+            ActionChains(self.driver).move_to_element_with_offset(
+                self._element, -10, -10).click().perform()
+        except MoveTargetOutOfBoundsException:
+            ActionChains(self.driver).move_to_element_with_offset(
+                self._element, size['width'] + 10, 10).click().perform()
 
     def double_click(self):
         """
@@ -957,6 +934,11 @@ class WebDriverElement(ElementAPI):
         self.scroll_to()
         ActionChains(self.driver).drag_and_drop(self._element, droppable._element).perform()
 
+    def _full_screen():
+        width = self.driver.execute_script("return Math.max(document.body.scrollWidth, document.body.offsetWidth);")
+        height = self.driver.execute_script("return Math.max(document.body.scrollHeight, document.body.offsetHeight);")
+        self.driver.set_window_size(width, height)
+
     def screenshot(self, name='', suffix='.png', full=False):
         name = name or ''
 
@@ -965,9 +947,17 @@ class WebDriverElement(ElementAPI):
         os.close(fd)
 
         if full:
-            self.parent.full_screen()
+            ori_window_size = self.driver.get_window_size()
+            self._full_screen()
+
         target = self.screenshot_as_png()
-        self.parent.recover_screen()
+
+        if full:
+            # Restore screen size
+            width = ori_window_size.get('width')
+            height = ori_window_size.get('height')
+            self.driver.set_window_size(width, height)
+
         target.save(filename)
 
         return filename
