@@ -4,21 +4,23 @@
 # Use of this source code is governed by a BSD-style
 # license that can be found in the LICENSE file.
 
-import re
+from __future__ import unicode_literals
 
+import mimetypes
+import re
+import time
+
+import lxml.html
 from lxml.cssselect import CSSSelector
 from zope.testbrowser.browser import Browser, ListControl, SubmitControl
 from splinter.element_list import ElementList
 from splinter.exceptions import ElementDoesNotExist
 from splinter.driver import DriverAPI, ElementAPI
 from splinter.driver.element_present import ElementPresentMixIn
+from splinter.driver.find_links import FindLinks
 from splinter.driver.xpath_utils import _concat_xpath_from_str
 from splinter.cookie_manager import CookieManagerAPI
 
-import mimetypes
-import lxml.html
-import time
-
 
 class CookieManager(CookieManagerAPI):
     def __init__(self, driver):
@@ -72,6 +74,8 @@ class ZopeTestBrowser(ElementPresentMixIn, DriverAPI):
         self._cookie_manager = CookieManager(self._browser)
         self._last_urls = []
 
+        self.links = FindLinks(self)
+
     def __enter__(self):
         return self
 
@@ -99,7 +103,12 @@ class ZopeTestBrowser(ElementPresentMixIn, DriverAPI):
 
     @property
     def htmltree(self):
-        return lxml.html.fromstring(self.html.decode("utf-8"))
+        try:
+            html = self.html.decode("utf-8")
+        except AttributeError:
+            html = self.html
+
+        return lxml.html.fromstring(html)
 
     @property
     def title(self):
@@ -132,13 +141,13 @@ class ZopeTestBrowser(ElementPresentMixIn, DriverAPI):
     def find_by_css(self, selector):
         xpath = CSSSelector(selector).path
         return self.find_by_xpath(
-            xpath, original_find="css", original_selector=selector
+            xpath, original_find="css", original_query=selector
         )
 
     def get_control(self, xpath_element):
         return xpath_element
 
-    def find_by_xpath(self, xpath, original_find=None, original_selector=None):
+    def find_by_xpath(self, xpath, original_find=None, original_query=None):
         html = self.htmltree
 
         elements = []
@@ -152,7 +161,7 @@ class ZopeTestBrowser(ElementPresentMixIn, DriverAPI):
                 elements.append(self.get_control(xpath_element))
 
         find_by = original_find or "xpath"
-        query = original_selector or xpath
+        query = original_query or xpath
 
         return ElementList(
             [ZopeTestBrowserElement(element, self) for element in elements],
@@ -162,27 +171,30 @@ class ZopeTestBrowser(ElementPresentMixIn, DriverAPI):
 
     def find_by_tag(self, tag):
         return self.find_by_xpath(
-            "//%s" % tag, original_find="tag", original_selector=tag
+            "//%s" % tag, original_find="tag", original_query=tag
         )
 
     def find_by_value(self, value):
-        return self.find_by_xpath(
-            '//*[@value="%s"]' % value, original_find="value", original_selector=value
+        elem = self.find_by_xpath(
+            '//*[@value="%s"]' % value, original_find="value", original_query=value
         )
+        if elem:
+            return elem
+        return self.find_by_xpath('//*[.="%s"]' % value)
 
     def find_by_text(self, text):
         xpath_str = _concat_xpath_from_str(text)
         return self.find_by_xpath(
             xpath_str,
             original_find="text",
-            original_selector=text,
+            original_query=text,
         )
 
     def find_by_id(self, id_value):
         return self.find_by_xpath(
             '//*[@id="%s"][1]' % id_value,
             original_find="id",
-            original_selector=id_value,
+            original_query=id_value,
         )
 
     def find_by_name(self, name):
@@ -259,7 +271,8 @@ class ZopeTestBrowser(ElementPresentMixIn, DriverAPI):
         filename = file_path.split("/")[-1]
         control = self._browser.getControl(name=name)
         content_type, _ = mimetypes.guess_type(file_path)
-        control.add_file(open(file_path), content_type, filename)
+        with open(file_path, 'rb') as f:
+            control.add_file(f, content_type, filename)
 
     def _find_links_by_xpath(self, xpath):
         html = self.htmltree
